- [DATA SOURCE]
    - Download link:
        - https://zenodo.org/records/6477509
    - Citation:
        - Wieczorek, M. A. (2022). InSight Crustal Thickness Archive [Data set]. Zenodo. https://doi.org/10.5281/zenodo.6477509


For info/sources on reference interior models, see:

1. https://markwieczorek.github.io/ctplanet/source/generated/ctplanet.ReadRefModel.html
2. https://github.com/MarkWieczorek/ctplanet/tree/74e8550080d4adc68ae291a500e8d198a40d437c/examples/Data/Mars-reference-interior-models


TODO:

- explain what `generate_registry_from_box.py` does and how to use it
- link to data files (including og registry!)
